@@ -27,7 +27,18 @@ class AliNas:
 
     @classmethod
     def list(cls):
-        response = nas_client.describe_file_systems()['FileSystems']['FileSystem']
+        response = []
+        while True:
+            page = 1
+            params = {
+                "PageSize": 100,
+                "PageNumber": page
+            }
+            ret = nas_client.describe_file_systems(params)
+            response.extend(ret['FileSystems']['FileSystem'])
+            if int(ret['PageNumber']) * int(ret['PageSize']) > int(ret['TotalCount']):
+                break
+            page += 1
         return [cls(nas_info) for nas_info in response]
 
     def delete(self):
